@@ -381,17 +381,19 @@ class TerraformTemplateParser(TemplateParser):
                         if isinstance(processed_resource, dict):
                             for name, properties in processed_resource.items():
                                 if isinstance(properties, list):
-                                    for property in properties:
+                                    for property_obj in properties:
                                         self.resource_types.append(resource_name.lower())
-                                        property["compiletime_identity"] = "%s.%s" % (resource_name.lower(), name)
+                                        if "compiletime_identity" not in property_obj:
+                                            property_obj["compiletime_identity"] = "%s.%s" % (resource_name.lower(), name)
                                         resources.append({
                                             "type" : resource_name,
                                             "name" : name,
-                                            "properties" : property
+                                            "properties" : property_obj
                                         })    
                                 else:
                                     self.resource_types.append(resource_name.lower())
-                                    properties["compiletime_identity"] = "%s.%s" % (resource_name.lower(), name)
+                                    if "compiletime_identity" not in properties:
+                                        properties["compiletime_identity"] = "%s.%s" % (resource_name.lower(), name)
                                     resources.append({
                                         "type" : resource_name,
                                         "name" : name,
@@ -492,16 +494,35 @@ class TerraformTemplateParser(TemplateParser):
             for group in groups:
                 updated_group, _ = self.process_resource(group, count)
                 param_str.replace(group, updated_group)
-        
+
         groups = re.findall(r'^[(].*[,].*[)]|.* ([(].*[)])', param_str, re.I)
         if groups:
             for group in groups:
                 parameter_str = re.findall("(?<=\().*(?=\))", group)[0]
                 updated_group = self.process_expression_parameters(parameter_str, count)
                 param_str.replace(group, updated_group)
-        
+
         return param_str
 
+    # TODO: Fix this method
+    # def process_expression_parameters(self, param_str, count):
+        
+    #     groups = re.findall(r'([.a-zA-Z]+[(].*[,].*[)])', param_str, re.I)
+    #     if groups:
+    #         for group in groups:
+    #             updated_group, processed = self.process_resource(group, count)
+    #             if processed:
+    #                 param_str = param_str.replace(group, str(updated_group))
+        
+    #     groups = re.findall(r'^[(].*[,].*[)]|.* ([(].*[)])', param_str, re.I)
+    #     if groups:
+    #         for group in groups:
+    #             parameter_str = re.findall("(?<=\().*(?=\))", group)[0]
+    #             updated_group = self.process_expression_parameters(parameter_str, count)
+    #             param_str = param_str.replace(group, str(updated_group))
+        
+    #     return param_str
+
     def process_resource(self, resource, count=None, nested_string_params={}):
         """ 
         process the resource json and return the resource with updated values
@@ -534,7 +555,10 @@ class TerraformTemplateParser(TemplateParser):
                         del process_resource["count"]
                         self.count = i
                         for key, value in process_resource.items():
-                            if key == "dynamic" and value and isinstance(value, list) and isinstance(value[0], dict):
+                            if key in self.skip_key_to_process:
+                                new_resource_dict[key] = value
+                                continue
+                            elif key == "dynamic" and value and isinstance(value, list) and isinstance(value[0], dict):
                                 processed_resource, processed = self.process_resource({ "dynamic" : value }, count=i)
                                 if processed_resource and isinstance(processed_resource, dict):
                                     for res, val in processed_resource.items():
@@ -648,6 +672,10 @@ class TerraformTemplateParser(TemplateParser):
             matched_str = matched_str.strip()
             matched_str = self.parse_string(matched_str)
 
+            # if not re.match(r'^([.a-zA-Z]+[(].*[,].*[)])$', matched_str) and \
+            #     not re.match(r'^[(].*[,].*[)]|.* ([(].*[)])', matched_str):
+            #     matched_str = self.process_expression_parameters(matched_str, count)
+                
             result, res = self.check_numeric_value(matched_str)
             if result:
                 new_resource = res
